@@ -48,15 +48,18 @@ def __build_repository(repository_name, tag):
 
 def __build_environment(color, alb_arn, cluster_name):
     services_arn = ecs_manager.get_services_arn_for_color(color, cluster_name)
+    max_capacities = ecs_manager.get_services_resource_ids_for_colored_resources(services_arn)
+    resource_ids = ecs_manager.get_services_max_capacities_for_colored_resources(services_arn)
+
     ecs_services = list(map(
-        lambda x: EcsService(ecs_client=ecs_client, cluster_name=cluster_name, service_arn=x),
-        services_arn
+        lambda x, y, z: EcsService(ecs_client=ecs_client, application_autoscaling_client=application_autoscaling_client,
+                                   cluster_name=cluster_name, service_arn=x, max_capacity=y, resource_id=z),
+        services_arn, max_capacities, resource_ids
     ))
     return Environment(
         color=color,
         cluster_name=cluster_name,
         ecs_client=ecs_client,
-        application_autoscaling_client=application_autoscaling_client,
         ecs_services=[s for s in ecs_services if s],
         gw_target_group_arn=alb_manager.get_alb_target_group_arn(
             alb_arn, color, constant.TARGET_GROUP_GATEWAY_TYPE
